"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationRecordColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_FIELD_NUMBER: builtins.int
    SQL_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mapping: builtins.str
    sql_type: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping: builtins.str = ...,
        sql_type: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping", b"mapping", "name", b"name", "resource_info", b"resource_info", "sql_type", b"sql_type"]) -> None: ...

global___ApplicationRecordColumn = ApplicationRecordColumn

@typing_extensions.final
class ApplicationJSONMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_row_path", b"record_row_path", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationJSONMappingParameters = ApplicationJSONMappingParameters

@typing_extensions.final
class ApplicationCSVMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_DELIMITER_FIELD_NUMBER: builtins.int
    RECORD_COLUMN_DELIMITER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_delimiter: builtins.str
    record_column_delimiter: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_delimiter: builtins.str = ...,
        record_column_delimiter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_column_delimiter", b"record_column_delimiter", "record_row_delimiter", b"record_row_delimiter", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationCSVMappingParameters = ApplicationCSVMappingParameters

@typing_extensions.final
class ApplicationMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    CS_V_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_mapping_parameters(self) -> global___ApplicationJSONMappingParameters: ...
    @property
    def cs_v_mapping_parameters(self) -> global___ApplicationCSVMappingParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_mapping_parameters: global___ApplicationJSONMappingParameters | None = ...,
        cs_v_mapping_parameters: global___ApplicationCSVMappingParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationMappingParameters = ApplicationMappingParameters

@typing_extensions.final
class ApplicationRecordFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mapping_parameters(self) -> global___ApplicationMappingParameters: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping_parameters: global___ApplicationMappingParameters | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationRecordFormat = ApplicationRecordFormat

@typing_extensions.final
class ApplicationInputSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ENCODING_FIELD_NUMBER: builtins.int
    RECORD_COLUMNS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_encoding: builtins.str
    @property
    def record_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationRecordColumn]: ...
    @property
    def record_format(self) -> global___ApplicationRecordFormat: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_encoding: builtins.str = ...,
        record_columns: collections.abc.Iterable[global___ApplicationRecordColumn] | None = ...,
        record_format: global___ApplicationRecordFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_format", b"record_format", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_columns", b"record_columns", "record_encoding", b"record_encoding", "record_format", b"record_format", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputSchema = ApplicationInputSchema

@typing_extensions.final
class ApplicationKinesisStreamsInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationKinesisStreamsInput = ApplicationKinesisStreamsInput

@typing_extensions.final
class ApplicationKinesisFirehoseInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationKinesisFirehoseInput = ApplicationKinesisFirehoseInput

@typing_extensions.final
class ApplicationInputLambdaProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationInputLambdaProcessor = ApplicationInputLambdaProcessor

@typing_extensions.final
class ApplicationInputProcessingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_LAMBDA_PROCESSOR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def input_lambda_processor(self) -> global___ApplicationInputLambdaProcessor: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_lambda_processor: global___ApplicationInputLambdaProcessor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_lambda_processor", b"input_lambda_processor", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_lambda_processor", b"input_lambda_processor", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputProcessingConfiguration = ApplicationInputProcessingConfiguration

@typing_extensions.final
class ApplicationInputParallelism(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInputParallelism = ApplicationInputParallelism

@typing_extensions.final
class ApplicationInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    KINESIS_STREAMS_INPUT_FIELD_NUMBER: builtins.int
    KINESIS_FIREHOSE_INPUT_FIELD_NUMBER: builtins.int
    INPUT_PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    INPUT_PARALLELISM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name_prefix: builtins.str
    @property
    def input_schema(self) -> global___ApplicationInputSchema: ...
    @property
    def kinesis_streams_input(self) -> global___ApplicationKinesisStreamsInput: ...
    @property
    def kinesis_firehose_input(self) -> global___ApplicationKinesisFirehoseInput: ...
    @property
    def input_processing_configuration(self) -> global___ApplicationInputProcessingConfiguration: ...
    @property
    def input_parallelism(self) -> global___ApplicationInputParallelism: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name_prefix: builtins.str = ...,
        input_schema: global___ApplicationInputSchema | None = ...,
        kinesis_streams_input: global___ApplicationKinesisStreamsInput | None = ...,
        kinesis_firehose_input: global___ApplicationKinesisFirehoseInput | None = ...,
        input_processing_configuration: global___ApplicationInputProcessingConfiguration | None = ...,
        input_parallelism: global___ApplicationInputParallelism | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_parallelism", b"input_parallelism", "input_processing_configuration", b"input_processing_configuration", "input_schema", b"input_schema", "kinesis_firehose_input", b"kinesis_firehose_input", "kinesis_streams_input", b"kinesis_streams_input", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_parallelism", b"input_parallelism", "input_processing_configuration", b"input_processing_configuration", "input_schema", b"input_schema", "kinesis_firehose_input", b"kinesis_firehose_input", "kinesis_streams_input", b"kinesis_streams_input", "name_prefix", b"name_prefix", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationInput = ApplicationInput

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    INPUTS_FIELD_NUMBER: builtins.int
    APPLICATION_DESCRIPTION_FIELD_NUMBER: builtins.int
    APPLICATION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationInput]: ...
    application_description: builtins.str
    application_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        inputs: collections.abc.Iterable[global___ApplicationInput] | None = ...,
        application_description: builtins.str = ...,
        application_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_code", b"application_code", "application_description", b"application_description", "application_name", b"application_name", "inputs", b"inputs", "resource_info", b"resource_info"]) -> None: ...

global___Application = Application

@typing_extensions.final
class KinesisAnalytics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    APPLICATION_OUTPUT_FIELD_NUMBER: builtins.int
    APPLICATION_REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def application_output(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationOutput]: ...
    @property
    def application_reference_data_source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationReferenceDataSource]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        application_output: collections.abc.Iterable[global___ApplicationOutput] | None = ...,
        application_reference_data_source: collections.abc.Iterable[global___ApplicationReferenceDataSource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "application_output", b"application_output", "application_reference_data_source", b"application_reference_data_source"]) -> None: ...

global___KinesisAnalytics = KinesisAnalytics

@typing_extensions.final
class ApplicationOutputDestinationSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutputDestinationSchema = ApplicationOutputDestinationSchema

@typing_extensions.final
class ApplicationOutputLambdaOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputLambdaOutput = ApplicationOutputLambdaOutput

@typing_extensions.final
class ApplicationOutputKinesisFirehoseOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputKinesisFirehoseOutput = ApplicationOutputKinesisFirehoseOutput

@typing_extensions.final
class ApplicationOutputKinesisStreamsOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_arn", b"resource_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___ApplicationOutputKinesisStreamsOutput = ApplicationOutputKinesisStreamsOutput

@typing_extensions.final
class ApplicationOutputOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_SCHEMA_FIELD_NUMBER: builtins.int
    LAMBDA_OUTPUT_FIELD_NUMBER: builtins.int
    KINESIS_FIREHOSE_OUTPUT_FIELD_NUMBER: builtins.int
    KINESIS_STREAMS_OUTPUT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def destination_schema(self) -> global___ApplicationOutputDestinationSchema: ...
    @property
    def lambda_output(self) -> global___ApplicationOutputLambdaOutput: ...
    @property
    def kinesis_firehose_output(self) -> global___ApplicationOutputKinesisFirehoseOutput: ...
    @property
    def kinesis_streams_output(self) -> global___ApplicationOutputKinesisStreamsOutput: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_schema: global___ApplicationOutputDestinationSchema | None = ...,
        lambda_output: global___ApplicationOutputLambdaOutput | None = ...,
        kinesis_firehose_output: global___ApplicationOutputKinesisFirehoseOutput | None = ...,
        kinesis_streams_output: global___ApplicationOutputKinesisStreamsOutput | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_schema", b"destination_schema", "kinesis_firehose_output", b"kinesis_firehose_output", "kinesis_streams_output", b"kinesis_streams_output", "lambda_output", b"lambda_output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_schema", b"destination_schema", "kinesis_firehose_output", b"kinesis_firehose_output", "kinesis_streams_output", b"kinesis_streams_output", "lambda_output", b"lambda_output", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutputOutput = ApplicationOutputOutput

@typing_extensions.final
class ApplicationOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def output(self) -> global___ApplicationOutputOutput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        output: global___ApplicationOutputOutput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["output", b"output", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "output", b"output", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationOutput = ApplicationOutput

@typing_extensions.final
class ApplicationReferenceDataSourceRecordColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_FIELD_NUMBER: builtins.int
    SQL_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mapping: builtins.str
    sql_type: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping: builtins.str = ...,
        sql_type: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping", b"mapping", "name", b"name", "resource_info", b"resource_info", "sql_type", b"sql_type"]) -> None: ...

global___ApplicationReferenceDataSourceRecordColumn = ApplicationReferenceDataSourceRecordColumn

@typing_extensions.final
class ApplicationReferenceDataSourceJSONMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_row_path", b"record_row_path", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceJSONMappingParameters = ApplicationReferenceDataSourceJSONMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceCSVMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ROW_DELIMITER_FIELD_NUMBER: builtins.int
    RECORD_COLUMN_DELIMITER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_row_delimiter: builtins.str
    record_column_delimiter: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_row_delimiter: builtins.str = ...,
        record_column_delimiter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_column_delimiter", b"record_column_delimiter", "record_row_delimiter", b"record_row_delimiter", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceCSVMappingParameters = ApplicationReferenceDataSourceCSVMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceMappingParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    JSON_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    CS_V_MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def json_mapping_parameters(self) -> global___ApplicationReferenceDataSourceJSONMappingParameters: ...
    @property
    def cs_v_mapping_parameters(self) -> global___ApplicationReferenceDataSourceCSVMappingParameters: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        json_mapping_parameters: global___ApplicationReferenceDataSourceJSONMappingParameters | None = ...,
        cs_v_mapping_parameters: global___ApplicationReferenceDataSourceCSVMappingParameters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cs_v_mapping_parameters", b"cs_v_mapping_parameters", "json_mapping_parameters", b"json_mapping_parameters", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceMappingParameters = ApplicationReferenceDataSourceMappingParameters

@typing_extensions.final
class ApplicationReferenceDataSourceRecordFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAPPING_PARAMETERS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def mapping_parameters(self) -> global___ApplicationReferenceDataSourceMappingParameters: ...
    record_format_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mapping_parameters: global___ApplicationReferenceDataSourceMappingParameters | None = ...,
        record_format_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mapping_parameters", b"mapping_parameters", "record_format_type", b"record_format_type", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceRecordFormat = ApplicationReferenceDataSourceRecordFormat

@typing_extensions.final
class ApplicationReferenceDataSourceReferenceSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RECORD_ENCODING_FIELD_NUMBER: builtins.int
    RECORD_COLUMNS_FIELD_NUMBER: builtins.int
    RECORD_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    record_encoding: builtins.str
    @property
    def record_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationReferenceDataSourceRecordColumn]: ...
    @property
    def record_format(self) -> global___ApplicationReferenceDataSourceRecordFormat: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        record_encoding: builtins.str = ...,
        record_columns: collections.abc.Iterable[global___ApplicationReferenceDataSourceRecordColumn] | None = ...,
        record_format: global___ApplicationReferenceDataSourceRecordFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_format", b"record_format", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["record_columns", b"record_columns", "record_encoding", b"record_encoding", "record_format", b"record_format", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceReferenceSchema = ApplicationReferenceDataSourceReferenceSchema

@typing_extensions.final
class ApplicationReferenceDataSourceS3ReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    FILE_KEY_FIELD_NUMBER: builtins.int
    REFERENCE_ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    file_key: builtins.str
    reference_role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        file_key: builtins.str = ...,
        reference_role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "file_key", b"file_key", "reference_role_arn", b"reference_role_arn", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSourceS3ReferenceDataSource = ApplicationReferenceDataSourceS3ReferenceDataSource

@typing_extensions.final
class ApplicationReferenceDataSourceReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REFERENCE_SCHEMA_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    S3_REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def reference_schema(self) -> global___ApplicationReferenceDataSourceReferenceSchema: ...
    table_name: builtins.str
    @property
    def s3_reference_data_source(self) -> global___ApplicationReferenceDataSourceS3ReferenceDataSource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        reference_schema: global___ApplicationReferenceDataSourceReferenceSchema | None = ...,
        table_name: builtins.str = ...,
        s3_reference_data_source: global___ApplicationReferenceDataSourceS3ReferenceDataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reference_schema", b"reference_schema", "resource_info", b"resource_info", "s3_reference_data_source", b"s3_reference_data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["reference_schema", b"reference_schema", "resource_info", b"resource_info", "s3_reference_data_source", b"s3_reference_data_source", "table_name", b"table_name"]) -> None: ...

global___ApplicationReferenceDataSourceReferenceDataSource = ApplicationReferenceDataSourceReferenceDataSource

@typing_extensions.final
class ApplicationReferenceDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    REFERENCE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    @property
    def reference_data_source(self) -> global___ApplicationReferenceDataSourceReferenceDataSource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        reference_data_source: global___ApplicationReferenceDataSourceReferenceDataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reference_data_source", b"reference_data_source", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "reference_data_source", b"reference_data_source", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationReferenceDataSource = ApplicationReferenceDataSource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codeguruprofiler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_codeguruprofiler.proto\x12 oak9.tython.aws.codeguruprofiler\x1a\x13shared/shared.proto\"y\n\x15ProfilingGroupChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x13\n\x0b\x63hannel_uri\x18\x03 \x01(\t\"\x83\x04\n\x0eProfilingGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14profiling_group_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ompute_platform\x18\x03 \x01(\t\x12\x61\n\x11\x61gent_permissions\x18\x04 \x03(\x0b\x32\x46.oak9.tython.aws.codeguruprofiler.ProfilingGroup.AgentPermissionsEntry\x12m\n,anomaly_detection_notification_configuration\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.codeguruprofiler.ProfilingGroupChannel\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.codeguruprofiler.ProfilingGroup.TagsEntry\x1a\x37\n\x15\x41gentPermissionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x10\x43odeGuruProfiler\x12I\n\x0fprofiling_group\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.codeguruprofiler.ProfilingGroupb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codeguruprofiler_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._options = None
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_options = b'8\001'
  _PROFILINGGROUP_TAGSENTRY._options = None
  _PROFILINGGROUP_TAGSENTRY._serialized_options = b'8\001'
  _PROFILINGGROUPCHANNEL._serialized_start=89
  _PROFILINGGROUPCHANNEL._serialized_end=210
  _PROFILINGGROUP._serialized_start=213
  _PROFILINGGROUP._serialized_end=728
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_start=628
  _PROFILINGGROUP_AGENTPERMISSIONSENTRY._serialized_end=683
  _PROFILINGGROUP_TAGSENTRY._serialized_start=685
  _PROFILINGGROUP_TAGSENTRY._serialized_end=728
  _CODEGURUPROFILER._serialized_start=730
  _CODEGURUPROFILER._serialized_end=823
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MatchResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDE_RESOURCE_RULES_FIELD_NUMBER: builtins.int
    MATCH_POLICY_FIELD_NUMBER: builtins.int
    NAMESPACE_SELECTOR_FIELD_NUMBER: builtins.int
    OBJECT_SELECTOR_FIELD_NUMBER: builtins.int
    RESOURCE_RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def exclude_resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedRuleWithOperations]: ...
    match_policy: builtins.str
    @property
    def namespace_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def object_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedRuleWithOperations]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        exclude_resource_rules: collections.abc.Iterable[global___NamedRuleWithOperations] | None = ...,
        match_policy: builtins.str = ...,
        namespace_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        object_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        resource_rules: collections.abc.Iterable[global___NamedRuleWithOperations] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_resource_rules", b"exclude_resource_rules", "match_policy", b"match_policy", "namespace_selector", b"namespace_selector", "object_selector", b"object_selector", "resource_info", b"resource_info", "resource_rules", b"resource_rules"]) -> None: ...

global___MatchResources = MatchResources

@typing_extensions.final
class NamedRuleWithOperations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUPS_FIELD_NUMBER: builtins.int
    API_VERSIONS_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    RESOURCE_NAMES_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def api_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def api_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    scope: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_groups: collections.abc.Iterable[builtins.str] | None = ...,
        api_versions: collections.abc.Iterable[builtins.str] | None = ...,
        operations: collections.abc.Iterable[builtins.str] | None = ...,
        resource_names: collections.abc.Iterable[builtins.str] | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        scope: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_groups", b"api_groups", "api_versions", b"api_versions", "operations", b"operations", "resource_info", b"resource_info", "resource_names", b"resource_names", "resources", b"resources", "scope", b"scope"]) -> None: ...

global___NamedRuleWithOperations = NamedRuleWithOperations

@typing_extensions.final
class ParamKind(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "resource_info", b"resource_info"]) -> None: ...

global___ParamKind = ParamKind

@typing_extensions.final
class ParamRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___ParamRef = ParamRef

@typing_extensions.final
class ValidatingAdmissionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ValidatingAdmissionPolicySpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ValidatingAdmissionPolicySpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___ValidatingAdmissionPolicy = ValidatingAdmissionPolicy

@typing_extensions.final
class ValidatingAdmissionPolicyBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ValidatingAdmissionPolicyBindingSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ValidatingAdmissionPolicyBindingSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___ValidatingAdmissionPolicyBinding = ValidatingAdmissionPolicyBinding

@typing_extensions.final
class ValidatingAdmissionPolicyBindingList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatingAdmissionPolicyBinding]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ValidatingAdmissionPolicyBinding] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ValidatingAdmissionPolicyBindingList = ValidatingAdmissionPolicyBindingList

@typing_extensions.final
class ValidatingAdmissionPolicyBindingSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCH_RESOURCES_FIELD_NUMBER: builtins.int
    PARAM_REF_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def match_resources(self) -> global___MatchResources: ...
    @property
    def param_ref(self) -> global___ParamRef: ...
    policy_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        match_resources: global___MatchResources | None = ...,
        param_ref: global___ParamRef | None = ...,
        policy_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match_resources", b"match_resources", "param_ref", b"param_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["match_resources", b"match_resources", "param_ref", b"param_ref", "policy_name", b"policy_name", "resource_info", b"resource_info"]) -> None: ...

global___ValidatingAdmissionPolicyBindingSpec = ValidatingAdmissionPolicyBindingSpec

@typing_extensions.final
class ValidatingAdmissionPolicyList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatingAdmissionPolicy]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ValidatingAdmissionPolicy] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ValidatingAdmissionPolicyList = ValidatingAdmissionPolicyList

@typing_extensions.final
class ValidatingAdmissionPolicySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_POLICY_FIELD_NUMBER: builtins.int
    MATCH_CONSTRAINTS_FIELD_NUMBER: builtins.int
    PARAM_KIND_FIELD_NUMBER: builtins.int
    VALIDATIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    failure_policy: builtins.str
    @property
    def match_constraints(self) -> global___MatchResources: ...
    @property
    def param_kind(self) -> global___ParamKind: ...
    @property
    def validations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validation]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        failure_policy: builtins.str = ...,
        match_constraints: global___MatchResources | None = ...,
        param_kind: global___ParamKind | None = ...,
        validations: collections.abc.Iterable[global___Validation] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match_constraints", b"match_constraints", "param_kind", b"param_kind", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_policy", b"failure_policy", "match_constraints", b"match_constraints", "param_kind", b"param_kind", "resource_info", b"resource_info", "validations", b"validations"]) -> None: ...

global___ValidatingAdmissionPolicySpec = ValidatingAdmissionPolicySpec

@typing_extensions.final
class Validation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPRESSION_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    expression: builtins.str
    message: builtins.str
    reason: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        expression: builtins.str = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expression", b"expression", "message", b"message", "reason", b"reason", "resource_info", b"resource_info"]) -> None: ...

global___Validation = Validation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Devices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOT_HUBS_FIELD_NUMBER: builtins.int
    IOT_HUBS_CERTIFICATES_FIELD_NUMBER: builtins.int
    IOT_HUBS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def iot_hubs(self) -> global___IotHubs: ...
    @property
    def iot_hubs_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IotHubsCertificates]: ...
    @property
    def iot_hubs_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IotHubsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        iot_hubs: global___IotHubs | None = ...,
        iot_hubs_certificates: collections.abc.Iterable[global___IotHubsCertificates] | None = ...,
        iot_hubs_private_endpoint_connections: collections.abc.Iterable[global___IotHubsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["iot_hubs", b"iot_hubs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["iot_hubs", b"iot_hubs", "iot_hubs_certificates", b"iot_hubs_certificates", "iot_hubs_private_endpoint_connections", b"iot_hubs_private_endpoint_connections"]) -> None: ...

global___Microsoft_Devices = Microsoft_Devices

@typing_extensions.final
class Properties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FILE_UPLOAD_NOTIFICATIONS_FIELD_NUMBER: builtins.int
    MIN_TLS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    enable_file_upload_notifications: builtins.bool
    min_tls_version: builtins.str
    public_network_access: builtins.str
    def __init__(
        self,
        *,
        enable_file_upload_notifications: builtins.bool = ...,
        min_tls_version: builtins.str = ...,
        public_network_access: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_file_upload_notifications", b"enable_file_upload_notifications", "min_tls_version", b"min_tls_version", "public_network_access", b"public_network_access"]) -> None: ...

global___Properties = Properties

@typing_extensions.final
class IotHubsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsPrivateEndpointConnections = IotHubsPrivateEndpointConnections

@typing_extensions.final
class IotHubsEventHubEndpointsConsumerGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsEventHubEndpointsConsumerGroups = IotHubsEventHubEndpointsConsumerGroups

@typing_extensions.final
class IotHubsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    IS_VERIFIED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    certificate: builtins.str
    is_verified: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        certificate: builtins.str = ...,
        is_verified: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "is_verified", b"is_verified", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IotHubsCertificates = IotHubsCertificates

@typing_extensions.final
class IotHubs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class EventHubEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MessagingEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StorageEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_FQDN_LIST_FIELD_NUMBER: builtins.int
    AUTHORIZATION_POLICIES_FIELD_NUMBER: builtins.int
    CLOUD_TO_DEVICE_FIELD_NUMBER: builtins.int
    COMMENTS_FIELD_NUMBER: builtins.int
    DISABLE_DEVICE_S_A_S_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    DISABLE_MODULE_S_A_S_FIELD_NUMBER: builtins.int
    ENABLE_DATA_RESIDENCY_FIELD_NUMBER: builtins.int
    EVENT_HUB_ENDPOINTS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    IP_FILTER_RULES_FIELD_NUMBER: builtins.int
    MESSAGING_ENDPOINTS_FIELD_NUMBER: builtins.int
    NETWORK_RULE_SETS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    RESTRICT_OUTBOUND_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ROUTING_FIELD_NUMBER: builtins.int
    STORAGE_ENDPOINTS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    @property
    def identity(self) -> global___ArmIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def allowed_fqdn_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def authorization_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SharedAccessSignatureAuthorizationRule]: ...
    @property
    def cloud_to_device(self) -> global___CloudToDeviceProperties: ...
    comments: builtins.str
    disable_device_s_a_s: builtins.bool
    disable_local_auth: builtins.bool
    disable_module_s_a_s: builtins.bool
    enable_data_residency: builtins.bool
    @property
    def event_hub_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    features: builtins.str
    @property
    def ip_filter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpFilterRule]: ...
    @property
    def messaging_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def network_rule_sets(self) -> global___NetworkRuleSetProperties: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    restrict_outbound_network_access: builtins.bool
    @property
    def routing(self) -> global___RoutingProperties: ...
    @property
    def storage_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def sku(self) -> global___IotHubSkuInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> global___Properties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        identity: global___ArmIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        allowed_fqdn_list: collections.abc.Iterable[builtins.str] | None = ...,
        authorization_policies: collections.abc.Iterable[global___SharedAccessSignatureAuthorizationRule] | None = ...,
        cloud_to_device: global___CloudToDeviceProperties | None = ...,
        comments: builtins.str = ...,
        disable_device_s_a_s: builtins.bool = ...,
        disable_local_auth: builtins.bool = ...,
        disable_module_s_a_s: builtins.bool = ...,
        enable_data_residency: builtins.bool = ...,
        event_hub_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        features: builtins.str = ...,
        ip_filter_rules: collections.abc.Iterable[global___IpFilterRule] | None = ...,
        messaging_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_rule_sets: global___NetworkRuleSetProperties | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        restrict_outbound_network_access: builtins.bool = ...,
        routing: global___RoutingProperties | None = ...,
        storage_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sku: global___IotHubSkuInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: global___Properties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_to_device", b"cloud_to_device", "identity", b"identity", "network_rule_sets", b"network_rule_sets", "properties", b"properties", "resource_info", b"resource_info", "routing", b"routing", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_fqdn_list", b"allowed_fqdn_list", "authorization_policies", b"authorization_policies", "cloud_to_device", b"cloud_to_device", "comments", b"comments", "disable_device_s_a_s", b"disable_device_s_a_s", "disable_local_auth", b"disable_local_auth", "disable_module_s_a_s", b"disable_module_s_a_s", "enable_data_residency", b"enable_data_residency", "etag", b"etag", "event_hub_endpoints", b"event_hub_endpoints", "features", b"features", "identity", b"identity", "ip_filter_rules", b"ip_filter_rules", "location", b"location", "messaging_endpoints", b"messaging_endpoints", "name", b"name", "network_rule_sets", b"network_rule_sets", "private_endpoint_connections", b"private_endpoint_connections", "properties", b"properties", "resource_info", b"resource_info", "restrict_outbound_network_access", b"restrict_outbound_network_access", "routing", b"routing", "sku", b"sku", "storage_endpoints", b"storage_endpoints", "tags", b"tags"]) -> None: ...

global___IotHubs = IotHubs

@typing_extensions.final
class IotHubSkuInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name"]) -> None: ...

global___IotHubSkuInfo = IotHubSkuInfo

@typing_extensions.final
class RoutingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    ENRICHMENTS_FIELD_NUMBER: builtins.int
    FALLBACK_ROUTE_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    @property
    def endpoints(self) -> global___RoutingEndpoints: ...
    @property
    def enrichments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnrichmentProperties]: ...
    @property
    def fallback_route(self) -> global___FallbackRouteProperties: ...
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteProperties]: ...
    def __init__(
        self,
        *,
        endpoints: global___RoutingEndpoints | None = ...,
        enrichments: collections.abc.Iterable[global___EnrichmentProperties] | None = ...,
        fallback_route: global___FallbackRouteProperties | None = ...,
        routes: collections.abc.Iterable[global___RouteProperties] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "fallback_route", b"fallback_route"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoints", b"endpoints", "enrichments", b"enrichments", "fallback_route", b"fallback_route", "routes", b"routes"]) -> None: ...

global___RoutingProperties = RoutingProperties

@typing_extensions.final
class RouteProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    condition: builtins.str
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_enabled: builtins.bool
    name: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_enabled: builtins.bool = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "endpoint_names", b"endpoint_names", "is_enabled", b"is_enabled", "name", b"name", "source", b"source"]) -> None: ...

global___RouteProperties = RouteProperties

@typing_extensions.final
class FallbackRouteProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITION_FIELD_NUMBER: builtins.int
    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    condition: builtins.str
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_enabled: builtins.bool
    name: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        condition: builtins.str = ...,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_enabled: builtins.bool = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "endpoint_names", b"endpoint_names", "is_enabled", b"is_enabled", "name", b"name", "source", b"source"]) -> None: ...

global___FallbackRouteProperties = FallbackRouteProperties

@typing_extensions.final
class EnrichmentProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_NAMES_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def endpoint_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        endpoint_names: collections.abc.Iterable[builtins.str] | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_names", b"endpoint_names", "key", b"key", "value", b"value"]) -> None: ...

global___EnrichmentProperties = EnrichmentProperties

@typing_extensions.final
class RoutingEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_HUBS_FIELD_NUMBER: builtins.int
    SERVICE_BUS_QUEUES_FIELD_NUMBER: builtins.int
    SERVICE_BUS_TOPICS_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINERS_FIELD_NUMBER: builtins.int
    @property
    def event_hubs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingEventHubProperties]: ...
    @property
    def service_bus_queues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingServiceBusQueueEndpointProperties]: ...
    @property
    def service_bus_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingServiceBusTopicEndpointProperties]: ...
    @property
    def storage_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingStorageContainerProperties]: ...
    def __init__(
        self,
        *,
        event_hubs: collections.abc.Iterable[global___RoutingEventHubProperties] | None = ...,
        service_bus_queues: collections.abc.Iterable[global___RoutingServiceBusQueueEndpointProperties] | None = ...,
        service_bus_topics: collections.abc.Iterable[global___RoutingServiceBusTopicEndpointProperties] | None = ...,
        storage_containers: collections.abc.Iterable[global___RoutingStorageContainerProperties] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_hubs", b"event_hubs", "service_bus_queues", b"service_bus_queues", "service_bus_topics", b"service_bus_topics", "storage_containers", b"storage_containers"]) -> None: ...

global___RoutingEndpoints = RoutingEndpoints

@typing_extensions.final
class RoutingStorageContainerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    BATCH_FREQUENCY_IN_SECONDS_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    ENCODING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    FILE_NAME_FORMAT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    MAX_CHUNK_SIZE_IN_BYTES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    batch_frequency_in_seconds: builtins.int
    connection_string: builtins.str
    container_name: builtins.str
    encoding: builtins.str
    endpoint_uri: builtins.str
    file_name_format: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    max_chunk_size_in_bytes: builtins.int
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        batch_frequency_in_seconds: builtins.int = ...,
        connection_string: builtins.str = ...,
        container_name: builtins.str = ...,
        encoding: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        file_name_format: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        max_chunk_size_in_bytes: builtins.int = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "batch_frequency_in_seconds", b"batch_frequency_in_seconds", "connection_string", b"connection_string", "container_name", b"container_name", "encoding", b"encoding", "endpoint_uri", b"endpoint_uri", "file_name_format", b"file_name_format", "id", b"id", "identity", b"identity", "max_chunk_size_in_bytes", b"max_chunk_size_in_bytes", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingStorageContainerProperties = RoutingStorageContainerProperties

@typing_extensions.final
class RoutingServiceBusTopicEndpointProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingServiceBusTopicEndpointProperties = RoutingServiceBusTopicEndpointProperties

@typing_extensions.final
class RoutingServiceBusQueueEndpointProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingServiceBusQueueEndpointProperties = RoutingServiceBusQueueEndpointProperties

@typing_extensions.final
class RoutingEventHubProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_TYPE_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ENTITY_PATH_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    authentication_type: builtins.str
    connection_string: builtins.str
    endpoint_uri: builtins.str
    entity_path: builtins.str
    id: builtins.str
    @property
    def identity(self) -> global___ManagedIdentity: ...
    name: builtins.str
    resource_group: builtins.str
    subscription_id: builtins.str
    def __init__(
        self,
        *,
        authentication_type: builtins.str = ...,
        connection_string: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        entity_path: builtins.str = ...,
        id: builtins.str = ...,
        identity: global___ManagedIdentity | None = ...,
        name: builtins.str = ...,
        resource_group: builtins.str = ...,
        subscription_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_type", b"authentication_type", "connection_string", b"connection_string", "endpoint_uri", b"endpoint_uri", "entity_path", b"entity_path", "id", b"id", "identity", b"identity", "name", b"name", "resource_group", b"resource_group", "subscription_id", b"subscription_id"]) -> None: ...

global___RoutingEventHubProperties = RoutingEventHubProperties

@typing_extensions.final
class ManagedIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___ManagedIdentity = ManagedIdentity

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class NetworkRuleSetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLY_TO_BUILT_IN_EVENT_HUB_ENDPOINT_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    apply_to_built_in_event_hub_endpoint: builtins.bool
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkRuleSetIpRule]: ...
    def __init__(
        self,
        *,
        apply_to_built_in_event_hub_endpoint: builtins.bool = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___NetworkRuleSetIpRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_to_built_in_event_hub_endpoint", b"apply_to_built_in_event_hub_endpoint", "default_action", b"default_action", "ip_rules", b"ip_rules"]) -> None: ...

global___NetworkRuleSetProperties = NetworkRuleSetProperties

@typing_extensions.final
class NetworkRuleSetIpRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    FILTER_NAME_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    filter_name: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        filter_name: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "filter_name", b"filter_name", "ip_mask", b"ip_mask"]) -> None: ...

global___NetworkRuleSetIpRule = NetworkRuleSetIpRule

@typing_extensions.final
class IpFilterRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    FILTER_NAME_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    filter_name: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        filter_name: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "filter_name", b"filter_name", "ip_mask", b"ip_mask"]) -> None: ...

global___IpFilterRule = IpFilterRule

@typing_extensions.final
class CloudToDeviceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_TTL_AS_ISO8601_FIELD_NUMBER: builtins.int
    FEEDBACK_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    default_ttl_as_iso8601: builtins.str
    @property
    def feedback(self) -> global___FeedbackProperties: ...
    max_delivery_count: builtins.int
    def __init__(
        self,
        *,
        default_ttl_as_iso8601: builtins.str = ...,
        feedback: global___FeedbackProperties | None = ...,
        max_delivery_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feedback", b"feedback"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_ttl_as_iso8601", b"default_ttl_as_iso8601", "feedback", b"feedback", "max_delivery_count", b"max_delivery_count"]) -> None: ...

global___CloudToDeviceProperties = CloudToDeviceProperties

@typing_extensions.final
class FeedbackProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_DURATION_AS_ISO8601_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    TTL_AS_ISO8601_FIELD_NUMBER: builtins.int
    lock_duration_as_iso8601: builtins.str
    max_delivery_count: builtins.int
    ttl_as_iso8601: builtins.str
    def __init__(
        self,
        *,
        lock_duration_as_iso8601: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        ttl_as_iso8601: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_duration_as_iso8601", b"lock_duration_as_iso8601", "max_delivery_count", b"max_delivery_count", "ttl_as_iso8601", b"ttl_as_iso8601"]) -> None: ...

global___FeedbackProperties = FeedbackProperties

@typing_extensions.final
class SharedAccessSignatureAuthorizationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_NAME_FIELD_NUMBER: builtins.int
    PRIMARY_KEY_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    SECONDARY_KEY_FIELD_NUMBER: builtins.int
    key_name: builtins.str
    primary_key: builtins.str
    rights: builtins.str
    secondary_key: builtins.str
    def __init__(
        self,
        *,
        key_name: builtins.str = ...,
        primary_key: builtins.str = ...,
        rights: builtins.str = ...,
        secondary_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_name", b"key_name", "primary_key", b"primary_key", "rights", b"rights", "secondary_key", b"secondary_key"]) -> None: ...

global___SharedAccessSignatureAuthorizationRule = SharedAccessSignatureAuthorizationRule

@typing_extensions.final
class ArmIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ArmIdentity = ArmIdentity
